@@ -8,7 +8,7 @@
 #include <skalibs/env.h>
 #include <skalibs/exec.h>
 
-#define USAGE "s6-envdir [ -I | -i ] [ -n ] [ -f ] [ -c nullchar ] dir prog..."
+#define USAGE "s6-envdir [ -I | -i ] [ -n ] [ -f ] [ -L ] [ -c nullchar ] dir prog..."
 
 int main (int argc, char const *const *argv)
 {
@@ -20,7 +20,7 @@ int main (int argc, char const *const *argv)
   PROG = "s6-envdir" ;
   for (;;)
   {
-    int opt = subgetopt_r(argc, argv, "Iinfc:", &l) ;
+    int opt = subgetopt_r(argc, argv, "IinfLc:", &l) ;
     if (opt == -1) break ;
     switch (opt)
     {
@@ -28,6 +28,7 @@ int main (int argc, char const *const *argv)
       case 'i' : insist = 1 ; break ;
       case 'n' : options |= SKALIBS_ENVDIR_NOCHOMP ; break ;
       case 'f' : options |= SKALIBS_ENVDIR_VERBATIM ; break ;
+      case 'L' : options |= SKALIBS_ENVDIR_NOCLAMP ; break ;
       case 'c' : nullis = *l.arg ; break ;
       default : strerr_dieusage(100, USAGE) ;
     }
